from cg.constants.priority import TrailblazerPriority

MAP_TO_TRAILBLAZER_PRIORITY: dict[int, TrailblazerPriority] = {
    0: TrailblazerPriority.LOW,
    1: TrailblazerPriority.NORMAL,
    2: TrailblazerPriority.HIGH,
    3: TrailblazerPriority.EXPRESS,
    4: TrailblazerPriority.NORMAL,
}
